#!/bin/sh

# This script is used by systemd /lib/systemd/system/adnisd.service.
# Use this script because systemd service file does not support conditional
# options below.
. /etc/centrifydc/scripts/functions.adnisd

PROG=${DAEMON##*/}

OPTIONS="$OPTIONS $@"

# Returns SUCCESS if we found adnisd
which adnisd > /dev/null 2>&1
if [ $? != 0 ]; then
    echo "Adnisd failed: adnisd cannot be found."
    exit 1
fi

# Returns SUCCESS if adnis version equal cdc version
NISVER=`$PROG -v|awk -F '[ -]' '{print $3}'`
CDCVER=`$ADINFO --version|awk -F '[ ()-]' '{print $4}'`
if [ "$NISVER" != "$CDCVER" ]; then
    echo " Adnisd failed: unmatched version: adnisd($NISVER),cdc($CDCVER)."
    exit 3
fi

# Returns SUCCESS if currently joined, and FAILURE if not.
$ADINFO --zone > /dev/null 2>&1
if [ $? -ne 0 ]; then
    echo " Adnisd failed: machine is not joined."
    exit 2
fi

#
# Wait for adclient
#
COUNT=20
while [ $COUNT -gt 1 ]; do
    $ADINFO --mode > /dev/null 2>&1   
    if [ $? -eq 0 ]; then
        break
    else
        sleep 1
    fi
    COUNT=`expr $COUNT - 1`
done

# If adclient is down, check cache files
$ADINFO --mode > /dev/null 2>&1
if [ $? -ne 0 ]; then
    CACHEDIR=/var/centrifydc/nis
    if [ ! -d "$CACHEDIR" ]; then
        echo "  Failed: Adclient not running and no cache files."
        exit 4
    fi
    PASSRET=`find "$CACHEDIR" -name "*:passwd:*.map" 2>/dev/null`
    GRPRET=`find "$CACHEDIR" -name "*:group:*.map" 2>/dev/null`
    if [ -z "$PASSRET" -o -z "$GRPRET" ]; then
        echo "Adnisd failed: Adclient not running and no cache files."
        exit 4
    fi
fi


/usr/sbin/adnisd $OPTIONS && wait_adnisd